Tutorials
=============

NCAR occasionally provides tutorials for wrf-python at various times 
throughout the year. 

Below are the links to the upcoming and past tutorials.

Upcoming Tutorials
---------------------

.. toctree::
   :maxdepth: 1
   
   tutorials/wrf_workshop_2019.rst
   

Past Tutorials
------------------

.. toctree::
   :maxdepth: 1

   tutorials/boise_2018.rst
   tutorials/wrf_workshop_2018.rst
   tutorials/tutorial_03_2018.rst
   tutorials/wrf_workshop_2017.rst
  
   
   
   
